==> breeze_update_3.6.05.tar.gz: manage/add_user.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
// Revised: 7/2/2012	ELL
// Adapted for website user page restrictions as well.
// Revised: 11/16/2012	ELL
// Added insertion of salt into password before encrypting.
//
	include ("check_session.php");

	$user_name = $_POST['user_name'];
	$password = $_POST['password'];
	$AccessLevel = $_POST['selectAccessLevel'];
	$email = $_POST['email'];
	$table = $_POST['table'];
	
	if ($table == "-not selected-")
	{
		echo "You must select a table first to add a user too.  Click <a href=\"manage_page_access.php\" title=\"here\">here</a> to select a table and try again.";
		exit;
	}
	
	//First check to see if user exists.
	if ((!$table) || ($table == ""))
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = '$user_name'";
	else
		$query = "SELECT * FROM " . $table . " WHERE `UserID` = '$user_name'";
		
	$result = mysql_query($query, $bwb_link);
	$row = mysql_fetch_array($result);
	$tmp_user_name = $row["UserID"];
	if ($tmp_user_name)
	{
		if ((!$table) || ($table == ""))
			echo "$user_name already exists in database.  Click <a href=\"users.php\" title=\"here\">here</a> to enter a different user name.";
		else
			echo "$user_name already exists in database.  Click <a href=\"manage_page_access.php\" title=\"here\">here</a> to enter a different user name.";
		exit;
	}
	
	// Insert salt into password.
	$pos = rand(0, (strlen($password)-1) );
	$pass1 = substr($password, 0, $pos);
	$pass2 = substr($password, $pos);
	if ($_POST['website_user'] == 1)
		$salted_pass = $pass1 . BWB_PUB_SALT . $pass2;
	else
		$salted_pass = $pass1 . BWB_SALT . $pass2;
	// Encrypt password using user name as key.
	$password = doEncrypt($salted_pass, $user_name);
	
	// Add user to database.
	if ((!$table) || ($table == ""))
		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "users SET UserID='$user_name', password='$password', AccessLevel='$AccessLevel'";
	else
		$query = "INSERT INTO " . $table . " SET UserID='$user_name', password='$password', AccessLevel='$AccessLevel', email='$email'";
			
	$result = mysql_query($query, $bwb_link);
	
	$_SESSION['last_user'] = $user_name;
	
	if ((!$table) || ($table == ""))
		header("Location: users.php");
	else
		header("Location: manage_page_access.php");
	
/////////////////////////////////
function doEncrypt($Data, $Key)
{
// encrypting  a[] with key k[] into e[]
// a[] = array to be encrypted
// k[] = key of truly random gibberish
// e[] = encrypted data

	for( $i = 0; $i < strlen($Data); $i++)
	{
		$c = substr($Data, $i, 1);
		$a[$i] = ord($c);
	}
	
	for( $i = 0; $i < strlen($Data); $i++)
	{
		if ($i < strlen($Key))
		{
			$c = substr($Key, $i, 1);
			$k[$i] = ord($c);
		}
		else
			$k[$i] = 65 + $i;
	}
	
	for ( $i=0; $i < strlen($Data); $i++ )
   	{
   		$e[$i] = $k[$i] ^ $a[$i];
   	}
	
	$encrypted = "";
	for ( $i = 0; $i < strlen($Data); $i++ )
	{
		$encrypted = $encrypted. decToHex($e[$i]);
	}
	return($encrypted);
	
}

function decToHex($dec)
{
	$hexStr = "0123456789ABCDEF";
	$low = $dec % 16;
	$high = ($dec - $low)/16;
	$hex = "";
	$hex = substr($hexStr, $high, 1) . substr($hexStr, $low, 1);
	return $hex;
}
	
?>

==> breeze_update_4.0.01.tar.gz: manage/add_user.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 2/7/2012	ELL
// Added table prefix handling.
// Revised: 7/2/2012	ELL
// Adapted for website user page restrictions as well.
// Revised: 11/16/2012	ELL
// Added insertion of salt into password before encrypting.
//
	include ("check_session.php");

	$user_name = $_POST['user_name'];
	$password = $_POST['password'];
	$AccessLevel = $_POST['selectAccessLevel'];
	$email = $_POST['email'];
	$table = $_POST['table'];
	
	if ($table == "-not selected-")
	{
		echo "You must select a table first to add a user too.  Click <a href=\"manage_page_access.php\" title=\"here\">here</a> to select a table and try again.";
		exit;
	}
	
	//First check to see if user exists.
	if ((!$table) || ($table == ""))
		$query = "SELECT * FROM " . BWB_TABLE_PREFIX . "users WHERE `UserID` = '$user_name'";
	else
		$query = "SELECT * FROM " . $table . " WHERE `UserID` = '$user_name'";
		
	$result = $bwb_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$tmp_user_name = $row["UserID"];
	if ($tmp_user_name)
	{
		if ((!$table) || ($table == ""))
			echo "$user_name already exists in database.  Click <a href=\"users.php\" title=\"here\">here</a> to enter a different user name.";
		else
			echo "$user_name already exists in database.  Click <a href=\"manage_page_access.php\" title=\"here\">here</a> to enter a different user name.";
		exit;
	}
	
	// Insert salt into password.
	$pos = rand(0, (strlen($password)-1) );
	$pass1 = substr($password, 0, $pos);
	$pass2 = substr($password, $pos);
	if ($_POST['website_user'] == 1)
		$salted_pass = $pass1 . BWB_PUB_SALT . $pass2;
	else
		$salted_pass = $pass1 . BWB_SALT . $pass2;
	// Encrypt password using user name as key.
	$password = doEncrypt($salted_pass, $user_name);
	
	// Add user to database.
	if ((!$table) || ($table == ""))
		$query = "INSERT INTO " . BWB_TABLE_PREFIX . "users SET UserID='$user_name', password='$password', AccessLevel='$AccessLevel'";
	else
		$query = "INSERT INTO " . $table . " SET UserID='$user_name', password='$password', AccessLevel='$AccessLevel', email='$email'";
			
	$cnt = $bwb_dbh->exec($query);
	
	$_SESSION['last_user'] = $user_name;
	
	if ((!$table) || ($table == ""))
		header("Location: users.php");
	else
		header("Location: manage_page_access.php");
	
/////////////////////////////////
function doEncrypt($Data, $Key)
{
// encrypting  a[] with key k[] into e[]
// a[] = array to be encrypted
// k[] = key of truly random gibberish
// e[] = encrypted data

	for( $i = 0; $i < strlen($Data); $i++)
	{
		$c = substr($Data, $i, 1);
		$a[$i] = ord($c);
	}
	
	for( $i = 0; $i < strlen($Data); $i++)
	{
		if ($i < strlen($Key))
		{
			$c = substr($Key, $i, 1);
			$k[$i] = ord($c);
		}
		else
			$k[$i] = 65 + $i;
	}
	
	for ( $i=0; $i < strlen($Data); $i++ )
   	{
   		$e[$i] = $k[$i] ^ $a[$i];
   	}
	
	$encrypted = "";
	for ( $i = 0; $i < strlen($Data); $i++ )
	{
		$encrypted = $encrypted. decToHex($e[$i]);
	}
	return($encrypted);
	
}

function decToHex($dec)
{
	$hexStr = "0123456789ABCDEF";
	$low = $dec % 16;
	$high = ($dec - $low)/16;
	$hex = "";
	$hex = substr($hexStr, $high, 1) . substr($hexStr, $low, 1);
	return $hex;
}
	
?>
